@@ -30,7 +30,7 @@ def get_lines_from_file(filename, lineno, context_lines,
     if loader is not None and hasattr(loader, "get_source"):
         try:
             source = loader.get_source(module_name)
-        except ImportError:
+        except (ImportError, IOError):
             # Traceback (most recent call last):
             #   File "/Users/dcramer/Development/django-sentry/sentry/client/handlers.py", line 31, in emit
             #     get_client().create_from_record(record, request=request)
@@ -62,15 +62,24 @@ def get_lines_from_file(filename, lineno, context_lines,
     upper_bound = min(lineno + 1 + context_lines, len(source))
 
     try:
-        pre_context = [line.strip('\r\n') for line in source[lower_bound:lineno]]
+        pre_context = [
+            line.strip('\r\n')
+            for line in source[lower_bound:lineno]
+        ]
         context_line = source[lineno].strip('\r\n')
-        post_context = [line.strip('\r\n') for line in
-                        source[(lineno + 1):upper_bound]]
+        post_context = [
+            line.strip('\r\n')
+            for line in source[(lineno + 1):upper_bound]
+        ]
     except IndexError:
         # the file may have changed since it was loaded into memory
         return None, None, None
 
-    return pre_context, context_line, post_context
+    return (
+        slim_string(pre_context),
+        slim_string(context_line),
+        slim_string(post_context)
+    )
 
 
 def label_from_frame(frame):
@@ -243,6 +252,14 @@ def slim_frame_data(frames, frame_allowance=25):
     return frames
 
 
+def slim_string(value, length=512):
+    if not value:
+        return value
+    if len(value) > length:
+        return value[:length - 3] + '...'
+    return value[:length]
+
+
 def get_stack_info(frames, transformer=transform, capture_locals=True,
                    frame_allowance=25):
     """
